===============================
JWT APNs Client
===============================


.. image:: https://img.shields.io/pypi/v/jwt_apns_client.svg
        :target: https://pypi.python.org/pypi/jwt_apns_client

.. image:: https://img.shields.io/travis/Mobelux/jwt_apns_client.svg
        :target: https://travis-ci.org/Mobelux/jwt_apns_client

.. image:: https://readthedocs.org/projects/jwt-apns-client/badge/?version=latest
        :target: https://jwt-apns-client.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


APNs client using JWT


* Free software: MIT license
* Documentation: https://jwt-apns-client.readthedocs.io.


Features
--------

* TODO

Credits
---------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
